@@ -2,11 +2,13 @@ package yqlib
 
 type ShellVariablesPreferences struct {
 	KeySeparator string
+	UnwrapScalar bool
 }
 
 func NewDefaultShellVariablesPreferences() ShellVariablesPreferences {
 	return ShellVariablesPreferences{
 		KeySeparator: "_",
+		UnwrapScalar: false,
 	}
 }
 
